summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/tags.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/tags.h')
-rw-r--r--crawl-ref/source/tags.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/tags.h b/crawl-ref/source/tags.h
index 1583d68bf2..e3ec18f659 100644
--- a/crawl-ref/source/tags.h
+++ b/crawl-ref/source/tags.h
@@ -50,7 +50,8 @@ enum tag_minor_version
TAG_MINOR_DISEASE = 1, // you.disease changed to an integer
TAG_MINOR_MAPCELL_NOCOLOUR = 2, // map_cell::colour removed
TAG_MINOR_SHOWTYPE_EXTENDED = 3, // map_cell::object stores more data
- TAG_MINOR_VERSION = 3 // Current version. (Keep equal to max.)
+ TAG_MINOR_SYNCH_TIME = 4, // player::synch_time removed
+ TAG_MINOR_VERSION = 4 // Current version. (Keep equal to max.)
};
struct enum_info